@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.33 2002/02/24 04:20:21 hadess Exp $
+ $Id: battstat_applet.c,v 1.34 2002/03/03 16:46:39 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -675,8 +675,12 @@ destroy_applet (GtkWidget *widget, gpointer data)
    gdk_bitmap_unref(pdata->mask);
    gdk_bitmap_unref(pdata->masky);
    gdk_bitmap_unref(pdata->pixmask);
-   g_free(pdata);
+
+   if (pdata->suspend_cmd)
+   	g_free (pdata->suspend_cmd);
    
+   g_free (pdata);
+
    return;
 }
 
@@ -1430,7 +1434,7 @@ battstat_applet_fill (PanelApplet *applet)
   battstat->last_pixmap_index = 1000;
   battstat->last_charging = 1000;
   battstat->colors_changed = TRUE;
-  battstat->suspend_cmd = FALSE;
+  battstat->suspend_cmd = NULL;
   battstat->orienttype = panel_applet_get_orient (applet);
   battstat->panelsize = panel_applet_get_size (applet);
   
