@@ -103,20 +103,6 @@ static const BonoboUIVerb applet_menu_verbs [] = {
     BONOBO_UI_VERB_END
 };
 
-/* and the XML definition for the popup menu */
-static const char applet_menu_xml [] =
-"<popup name=\"button3\">\n"
-"   <menuitem name=\"RunGTCD\" verb=\"RunGTCD\" _label=\"Run External CD Player\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-cdrom\"/>\n"
-"   <menuitem name=\"Properties\" verb=\"Properties\" _label=\"Properties...\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-"   <menuitem name=\"Help\" verb=\"Help\" _label=\"Help\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-"   <menuitem name=\"About\" verb=\"About\" _label=\"About ...\"\n"
-"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-"</popup>\n";
-
-
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_CDPlayerApplet_Factory",
 			     PANEL_TYPE_APPLET,
                              "CD-Player-Applet",
@@ -143,28 +129,35 @@ applet_fill (PanelApplet *applet)
     GtkWidget *cdplayer;
     CDPlayerData *cd;
     BonoboUIComponent *component;
+    GtkTooltips *tooltips;
     int err;
 
     cd = g_new0(CDPlayerData, 1);
-
+    cd->panel.applet = GTK_WIDGET (applet);
+    
     /* the rest of the widgets go in here */
     cdplayer = cd->panel.frame = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(cdplayer), GTK_SHADOW_IN);
     g_object_set_data (G_OBJECT(cdplayer), "cd-info", cd);
-    g_signal_connect (G_OBJECT(cdplayer), "destroy", G_CALLBACK (cdplayer_destroy), NULL);
     g_signal_connect_after (G_OBJECT (cdplayer), "realize", G_CALLBACK (cdplayer_realize), cd);
     gtk_widget_show(cdplayer);
+    
+    tooltips = gtk_tooltips_new ();
 
     cd->panel.box = NULL;
     cd->panel.play_control.stop = control_button_factory(stop_xpm, G_CALLBACK(cdplayer_stop), cd);
+    gtk_tooltips_set_tip (tooltips, cd->panel.play_control.stop, _("Stop"), NULL);
     cd->panel.play_control.play_pause = control_button_factory(play_pause_xpm, G_CALLBACK(cdplayer_play_pause), cd);
+    gtk_tooltips_set_tip (tooltips, cd->panel.play_control.play_pause, _("Play / Pause"), NULL);
     cd->panel.play_control.eject = control_button_factory(eject_xpm, G_CALLBACK(cdplayer_eject), cd);
+    gtk_tooltips_set_tip (tooltips, cd->panel.play_control.eject, _("Eject"), NULL);
     cd->panel.track_control.prev = control_button_factory(prev_xpm, G_CALLBACK(cdplayer_prev), cd);
+    gtk_tooltips_set_tip (tooltips, cd->panel.track_control.prev, _("Previous Track"), NULL);
     cd->panel.track_control.next = control_button_factory(next_xpm, G_CALLBACK(cdplayer_next), cd);
+    gtk_tooltips_set_tip (tooltips, cd->panel.track_control.next, _("Next Track"), NULL);
     led_init();
     led_create_widgets(&cd->panel.time, &cd->panel.track_control.display, (gpointer)cd);
 
-    cd->panel.applet = GTK_WIDGET (applet);
     gtk_container_add (GTK_CONTAINER (applet), cdplayer);
 
     /* panel_applet_add_preferences (applet, "/schemas/apps/cdplayer-applet/prefs", NULL); */
@@ -174,14 +167,16 @@ applet_fill (PanelApplet *applet)
     cd->orient = panel_applet_get_orient (PANEL_APPLET (applet));
     cd->size = panel_applet_get_size (PANEL_APPLET (applet));
 
-    g_signal_connect (applet, "destroy", G_CALLBACK (cdplayer_destroy), cd);
+    g_signal_connect (G_OBJECT (applet), "destroy", G_CALLBACK (cdplayer_destroy), cd);
     g_signal_connect (applet, "change_orient", G_CALLBACK (applet_change_orient), cd);
     g_signal_connect (applet, "change_size", G_CALLBACK (applet_change_size), cd);
 
-    panel_applet_setup_menu (PANEL_APPLET (applet),
-                             applet_menu_xml,
-                             applet_menu_verbs,
-                             cd);
+    panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+                                       NULL,
+                                       "GNOME_CDPlayerApplet.xml",
+                                       NULL,
+                                       applet_menu_verbs,
+                                       cd);
 
     component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
@@ -211,9 +206,8 @@ cdplayer_save_config(CDPlayerData *cd)
 static void
 cdplayer_destroy(GtkWidget * widget, gpointer data)
 {
-    CDPlayerData *cd;
+    CDPlayerData *cd = data;
 
-    cd = g_object_get_data(G_OBJECT(widget), "cd-info");
     if (cd->timeout != 0)
         gtk_timeout_remove(cd->timeout);
     cd->timeout = 0;
@@ -249,7 +243,7 @@ cdplayer_timeout_callback(gpointer data)
 static void
 start_gtcd_cb(GtkWidget *w, gpointer data)
 {
-    gnome_execute_shell(NULL, "gnome-cd");
+    g_spawn_command_line_async ("gnome-cd", NULL);
 }
 
 static void
@@ -489,6 +483,21 @@ setup_box(CDPlayerData* cd)
     gtk_widget_show_all(cd->panel.frame);
 }
 
+static gboolean 
+button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
+{
+    PanelApplet *applet = PANEL_APPLET (data);
+    /* Pass the right click to the PanelApplet */
+    if (event->button == 3) {
+    	GTK_WIDGET_CLASS (PANEL_APPLET_GET_CLASS (applet))->
+			  button_press_event (data, event);
+	return TRUE;
+    }
+    
+    return FALSE;
+    
+}
+
 static GtkWidget *
 control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
 {
@@ -501,8 +510,14 @@ control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
     GTK_WIDGET_UNSET_FLAGS(w, GTK_CAN_FOCUS);
     pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **)pixmap_data);
     image = gtk_image_new_from_pixbuf(pixbuf);
+    if (pixbuf)
+    	g_object_unref (pixbuf);
     gtk_widget_show(image);
     gtk_container_add(GTK_CONTAINER(w), image);
+    /* This is a hack to get the right click menu working with buttons
+    ** Should be removed when libpanelapplet is fixed */
+    g_signal_connect (G_OBJECT (w), "button_press_event",
+    		      G_CALLBACK (button_press_hack), cd->panel.applet);
     g_signal_connect(G_OBJECT(w), "clicked",
                      G_CALLBACK(func), cd);
     gtk_widget_show(w);
