@@ -94,10 +94,14 @@ load_theme (EyesApplet *eyes_applet, const gchar *theme_dir)
         
         parse_theme_file (eyes_applet, theme_file);
         fclose (theme_file);
-        
+
         eyes_applet->theme_name = g_strdup (theme_dir);
-        
+       
+        if (eyes_applet->eye_image)
+        	g_object_unref (eyes_applet->eye_image);
         eyes_applet->eye_image = gdk_pixbuf_new_from_file (eyes_applet->eye_filename, NULL);
+        if (eyes_applet->pupil_image)
+        	g_object_unref (eyes_applet->pupil_image);
         eyes_applet->pupil_image = gdk_pixbuf_new_from_file (eyes_applet->pupil_filename, NULL);
 
 	eyes_applet->eye_height = gdk_pixbuf_get_height (eyes_applet->eye_image);
@@ -133,6 +137,7 @@ theme_selected_cb (GtkTreeSelection *selection, gpointer data)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gchar *theme;
+	gchar *theme_dir;
 	
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
 		return;
@@ -141,6 +146,13 @@ theme_selected_cb (GtkTreeSelection *selection, gpointer data)
 	
 	g_return_if_fail (theme);
 	
+	theme_dir = g_strdup_printf ("%s/", theme);
+	if (!g_strcasecmp (theme_dir, eyes_applet->theme_dir)) {
+		g_free (theme_dir);
+		return;
+	}
+	g_free (theme_dir);
+		
 	destroy_eyes (eyes_applet);
         destroy_theme (eyes_applet);
         load_theme (eyes_applet, theme);
@@ -223,13 +235,25 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
                         while ((dp = readdir (dfd)) != NULL) {
                                 if (dp->d_name[0] != '.') {
                                         gchar *elems[2] = {NULL, NULL };
+                                        gchar *theme_dir;
 					elems[0] = filename;
                                         strcpy (filename, 
                                                 theme_directories[i]);
                                         strcat (filename, dp->d_name);
-                                        /* FIXME: highlight to current theme */
                                         gtk_list_store_insert (model, &iter, 0);
                                         gtk_list_store_set (model, &iter, 0, &filename, -1);
+                                        theme_dir = g_strdup_printf ("%s/", filename);
+                                        if (!g_strcasecmp (eyes_applet->theme_dir, theme_dir)) {
+                                        	GtkTreePath *path;
+                                        	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
+                                                        			&iter);
+                                                gtk_tree_view_set_cursor (GTK_TREE_VIEW (tree), 
+                                                			  path, 
+                                                			  NULL, 
+                                                			  FALSE);
+                                                gtk_tree_path_free (path);
+                                        }
+                                        g_free (theme_dir);
                                 }
                         }
                         closedir (dfd);
