@@ -1,7 +1,7 @@
 #ifndef __WEATHER_H_
 #define __WEATHER_H_
 
-/* $Id: weather.h,v 1.11 2002/02/10 17:20:36 kevinv Exp $ */
+/* $Id: weather.h,v 1.15 2002/03/01 04:53:15 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -24,16 +24,13 @@
 
 G_BEGIN_DECLS
 
-#define WEATHER_LOCATION_NAME_MAX_LEN 100
-#define WEATHER_LOCATION_CODE_LEN     4
-#define WEATHER_LOCATION_ZONE_LEN     7
-#define WEATHER_LOCATION_RADAR_LEN    3
+#define WEATHER_LOCATION_CODE_LEN 4
 
 struct _WeatherLocation {
-    gchar name[WEATHER_LOCATION_NAME_MAX_LEN + 1];
-    gchar code[WEATHER_LOCATION_CODE_LEN + 1];
-    gchar zone[WEATHER_LOCATION_ZONE_LEN + 1];
-    gchar radar[WEATHER_LOCATION_RADAR_LEN + 1];
+    gchar *name;
+    gchar *code;
+    gchar *zone;
+    gchar *radar;
 };
 
 typedef struct _WeatherLocation WeatherLocation;
@@ -189,21 +186,23 @@ struct _WeatherInfo {
     gchar *iwin_buffer;
     gchar *met_buffer;
     gchar *radar_buffer;
+    GdkPixbufLoader *radar_loader;
     GdkPixmap *radar;
     GnomeVFSAsyncHandle *metar_handle;
     GnomeVFSAsyncHandle *iwin_handle;
     GnomeVFSAsyncHandle *wx_handle;
     GnomeVFSAsyncHandle *met_handle;
     gboolean requests_pending;
+    gpointer applet;
 };
 
 typedef struct _WeatherInfo WeatherInfo;
 
 typedef void (*WeatherInfoFunc) (WeatherInfo *info);
 
-extern gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, WeatherInfoFunc cb);
-#define weather_info_new(location,cb) _weather_info_fill(NULL, (location), (cb))
-#define weather_info_update(info,cb) _weather_info_fill((info), NULL, (cb));
+extern gboolean _weather_info_fill (gpointer applet, WeatherInfo *info, WeatherLocation *location, WeatherInfoFunc cb);
+#define weather_info_new(applet, location,cb) _weather_info_fill((applet), NULL, (location), (cb))
+#define weather_info_update(applet, info,cb) _weather_info_fill((applet), (info), NULL, (cb));
 extern WeatherInfo *weather_info_clone (const WeatherInfo *info);
 extern void weather_info_free (WeatherInfo *info);
 
@@ -229,6 +228,8 @@ extern GdkPixmap *weather_info_get_radar (WeatherInfo *info);
 extern const gchar *weather_info_get_temp_summary (WeatherInfo *info);
 extern gchar *weather_info_get_weather_summary (WeatherInfo *info);
 
+extern void update_finish (WeatherInfo *info);
+
 extern time_t make_time (gint date, gint hour, gint min);
 
 extern void _weather_info_get_pixmap (WeatherInfo *info, gboolean mini, GdkPixmap **pixmap, GdkBitmap **mask);
