@@ -7,6 +7,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gnome.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
@@ -22,6 +26,27 @@
 #define PROP_SPEED		5
 #define PROP_SIZE		6
 
+void
+properties_set_insensitive(MultiloadApplet *ma)
+{
+	gint i, total_graphs, last_graph;
+	
+	total_graphs = 0;
+	last_graph = 0;
+		
+	for (i = 0; i < 5; i++)
+		if (ma->graphs[i]->visible)
+		{
+			last_graph = i;
+			total_graphs++;
+		}
+			
+	if (total_graphs < 2)
+		gtk_widget_set_sensitive(ma->check_boxes[last_graph], FALSE);
+		
+	return;
+}
+
 void
 properties_close_cb(GtkWidget *widget, gint arg, gpointer data)
 {
@@ -36,7 +61,7 @@ void
 property_toggled_cb(GtkWidget *widget, gpointer name)
 {
 	MultiloadApplet *ma;
-	gint prop_type;
+	gint prop_type, i;
 	gboolean active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	
 	ma = g_object_get_data(G_OBJECT(widget), "user_data");
@@ -51,47 +76,18 @@ property_toggled_cb(GtkWidget *widget, gpointer name)
 	
 	if (active)
 	{
-		switch(prop_type)
-		{
-			case PROP_CPU:
-			{
-				ma->graphs[prop_type] = cpuload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_MEM:
-			{
-				ma->graphs[prop_type] = memload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_NET:
-			{
-				ma->graphs[prop_type] = netload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_SWAP:
-			{
-				ma->graphs[prop_type] = swapload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_AVG:
-			{
-				ma->graphs[prop_type] = loadavg_applet_new(ma->applet, NULL);
-				break;
-			}
-			default:
-				g_assert_not_reached();
-		}
-		
-		gtk_box_pack_start(GTK_BOX(ma->box), ma->graphs[prop_type]->main_widget, FALSE, FALSE, 1);
-		gtk_widget_show_all(ma->box);
+		for (i = 0; i < 5; i++)
+			gtk_widget_set_sensitive(ma->check_boxes[i], TRUE);	
+		gtk_widget_show_all (ma->graphs[prop_type]->main_widget);
+		ma->graphs[prop_type]->visible = TRUE;
 		load_graph_start(ma->graphs[prop_type]);
 	}
 	else
 	{
 		load_graph_stop(ma->graphs[prop_type]);
-		gtk_widget_destroy(ma->graphs[prop_type]->main_widget);
-		load_graph_unalloc(ma->graphs[prop_type]);
-		g_free(ma->graphs[prop_type]);
+		gtk_widget_hide (ma->graphs[prop_type]->main_widget);
+		ma->graphs[prop_type]->visible = FALSE;
+		properties_set_insensitive(ma);
 	}
 	
 	return;
@@ -120,12 +116,10 @@ spin_button_changed_cb(GtkWidget *widget, gpointer name)
 		{
 			for (i = 0; i < 5; i++)
 			{
-				if (!ma->graphs[i]->visible)
-					continue;
-					
 				load_graph_stop(ma->graphs[i]);
 				ma->graphs[i]->speed = value;
-				load_graph_start(ma->graphs[i]);
+				if (ma->graphs[i]->visible)
+					load_graph_start(ma->graphs[i]);
 			}
 			
 			break;
@@ -134,15 +128,18 @@ spin_button_changed_cb(GtkWidget *widget, gpointer name)
 		{
 			for (i = 0; i < 5; i++)
 			{
-				if (!ma->graphs[i]->visible)
-					continue;
-					
-				ma->graphs[i]->size = value;
+				ma->graphs[i]->size = value ;
 				
 				if (ma->graphs[i]->orient)
-					gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->pixel_size, ma->graphs[i]->size);
+					gtk_widget_set_size_request (
+						ma->graphs[i]->main_widget, 
+						ma->graphs[i]->pixel_size, 
+						ma->graphs[i]->size);
 			    else
-					gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->size, ma->graphs[i]->pixel_size);
+					gtk_widget_set_size_request (
+						ma->graphs[i]->main_widget, 
+						ma->graphs[i]->size, 
+						ma->graphs[i]->pixel_size);
 			}
 			
 			break;
@@ -163,32 +160,25 @@ add_page(GtkWidget *notebook, gchar *label)
 	
 	page = gtk_hbox_new(TRUE, 0);
 	page_label = gtk_label_new(label);
-	
+	gtk_container_set_border_width(GTK_CONTAINER(page), 3);
+		
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page, page_label);
 	
 	return page;
 }
 
-/* close the color selection dialog */
+/* save the selected color to gconf and apply it on the applet */
 void
-color_selector_close_cb(GtkWidget *widget, gpointer dialog)
+color_picker_set_cb(GnomeColorPicker *color_picker, guint arg1, guint arg2, guint arg3, guint arg4, gpointer object)
 {
-	gtk_widget_destroy(GTK_WIDGET(dialog));
-	
-	return;
-}
-
-/* saves the currently selected color */
-void
-color_selector_ok_cb(GtkWidget *widget, gpointer dialog)
-{
-	gint prop_type, i;
-	GdkColor *color;
 	gchar color_string[8], *gconf_path;
+	guint8 red, green, blue, alpha, prop_type;
 	MultiloadApplet *ma;
 	
-	ma = g_object_get_data(G_OBJECT(dialog), "applet");	
-	gconf_path = g_object_get_data(G_OBJECT(dialog), "gconf_path");
+	gconf_path = g_object_get_data(G_OBJECT(object), "gconf_path");
+	ma = g_object_get_data(G_OBJECT(object), "applet");	
+	
+	prop_type = 0;
 	
 	if (strstr(gconf_path, "cpuload"))
 		prop_type = PROP_CPU;
@@ -199,59 +189,18 @@ color_selector_ok_cb(GtkWidget *widget, gpointer dialog)
 	else if (strstr(gconf_path, "swapload"))
 		prop_type = PROP_SWAP;
 	else
-		prop_type = PROP_AVG;
+		g_assert_not_reached();
 		
-	color = g_new0(GdkColor, 1);
+	gnome_color_picker_get_i8(color_picker, &red, &green, &blue, &alpha);
 	
-	gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(dialog)->colorsel), color);
-	snprintf(color_string, 8, "#%02X%02X%02X", (guint)color->red / 256, (guint)color->green / 256, (guint)color->blue / 256);
+	snprintf(color_string, 8, "#%02X%02X%02X", red, green, blue);
 	panel_applet_gconf_set_string(PANEL_APPLET(ma->applet), gconf_path, color_string, NULL);
 	
-	for (i = 0; i < ma->graphs[prop_type]->n; i++)
-		gdk_color_parse(color_string, &(ma->graphs[prop_type]->colors[i]));
+	gdk_color_parse(color_string, 
+			&(ma->graphs[prop_type]->colors[g_ascii_digit_value(gconf_path[strlen(gconf_path) - 1]) ]) );
 	
 	ma->graphs[prop_type]->colors_allocated = FALSE;	
 	
-	color_selector_close_cb(NULL, dialog);
-		
-	return;
-}
-
-/* popup a color selector dialog */
-void
-show_color_selector_cb(GtkWidget *widget, gpointer object)
-{
-	GtkWidget *dialog;
-	GdkColor *color;
-	gchar *gconf_path, *color_string;
-	MultiloadApplet *ma;
-	
-	gconf_path = g_object_get_data(G_OBJECT(object), "gconf_path");
-	ma = g_object_get_data(G_OBJECT(object), "applet");
-
-	color = g_new0(GdkColor, 1);
-	dialog = gtk_color_selection_dialog_new("Color");
-
-	g_object_set_data(G_OBJECT(dialog), "applet", ma);
-	g_object_set_data(G_OBJECT(dialog), "gconf_path", gconf_path);
-	
-	color_string = panel_applet_gconf_get_string(PANEL_APPLET(ma->applet), gconf_path, NULL);
-			
-	gdk_color_parse(color_string, color);
-	gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(dialog)->colorsel), color);
-	
-	g_signal_connect(G_OBJECT(dialog), "destroy", G_CALLBACK(gtk_widget_destroyed), &dialog);
-	g_signal_connect(G_OBJECT(GTK_COLOR_SELECTION_DIALOG(dialog)->cancel_button), "clicked",
-							G_CALLBACK(color_selector_close_cb), dialog);
-	g_signal_connect(G_OBJECT(GTK_COLOR_SELECTION_DIALOG(dialog)->ok_button), "clicked",
-							G_CALLBACK(color_selector_ok_cb), dialog);
-								
-	gtk_widget_show_all(dialog);
-	
-	gtk_widget_hide(GTK_COLOR_SELECTION_DIALOG(dialog)->help_button);
-	
-	g_free(color);
-	
 	return;
 }
 
@@ -261,27 +210,32 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 {
 	GtkWidget *vbox;
 	GtkWidget *label;
-	GtkWidget *button;
 	GtkWidget *object;
-/*	gchar *color_string; */
+	GtkWidget *color_picker;
+	gchar *color_string;
+	gint red, green, blue;
 	
+	color_string = panel_applet_gconf_get_string(ma->applet, gconf_path, NULL);
+	red = g_ascii_xdigit_value(color_string[1]) * 16 + g_ascii_xdigit_value(color_string[2]);
+	green = g_ascii_xdigit_value(color_string[3]) * 16 + g_ascii_xdigit_value(color_string[4]);
+	blue = g_ascii_xdigit_value(color_string[5]) * 16 + g_ascii_xdigit_value(color_string[6]);
+		
 	object = gtk_label_new("I will never be seen"); /* this is used instead of a structure */
-	button = gtk_button_new();
-	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
 	vbox = gtk_vbox_new(FALSE, 0);
 	label = gtk_label_new(name);
+	color_picker = gnome_color_picker_new();
 	
-	gtk_container_add(GTK_CONTAINER(button), vbox);
-	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), color_picker, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 2);
 	
-	gtk_box_pack_start(GTK_BOX(page), button, TRUE, TRUE, 3);
-	
-/*	color_string = panel_applet_gconf_get_string(PANEL_APPLET(ma->applet), gconf_path, NULL); */
+	gtk_box_pack_start(GTK_BOX(page), vbox, FALSE, FALSE, 0);	
 	
 	g_object_set_data(G_OBJECT(object), "gconf_path", gconf_path);
 	g_object_set_data(G_OBJECT(object), "applet", ma);
-	
-	g_signal_connect(G_OBJECT(button), "clicked", G_CALLBACK(show_color_selector_cb), object);
+
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), red, green, blue, 0);	
+
+	g_signal_connect(G_OBJECT(color_picker), "color_set", G_CALLBACK(color_picker_set_cb), object);
 	
 	return;
 }
@@ -308,7 +262,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	
 	check_box = gtk_check_button_new_with_mnemonic(_("_Processor"));
-	
+	ma->check_boxes[0] = check_box;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_box),
 				panel_applet_gconf_get_bool(ma->applet, "view_cpuload", NULL));
 	g_object_set_data(G_OBJECT(check_box), "user_data", ma);
@@ -318,6 +272,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start(GTK_BOX(hbox), check_box, FALSE, FALSE, 2);
 	
 	check_box = gtk_check_button_new_with_mnemonic(_("_Memory"));
+	ma->check_boxes[1] = check_box;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_box),
 				panel_applet_gconf_get_bool(ma->applet, "view_memload", NULL));
 	g_object_set_data(G_OBJECT(check_box), "user_data", ma);
@@ -327,6 +282,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start(GTK_BOX(hbox), check_box, FALSE, FALSE, 2);
 	
 	check_box = gtk_check_button_new_with_mnemonic(_("_Network"));
+	ma->check_boxes[2] = check_box;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_box),
 				panel_applet_gconf_get_bool(ma->applet, "view_netload", NULL));
 	g_object_set_data(G_OBJECT(check_box), "user_data", ma);
@@ -336,6 +292,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start(GTK_BOX(hbox), check_box, FALSE, FALSE, 2);
 	
 	check_box = gtk_check_button_new_with_mnemonic(_("_Swap File"));
+	ma->check_boxes[3] = check_box;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_box),
 				panel_applet_gconf_get_bool(ma->applet, "view_swapload", NULL));
 	g_object_set_data(G_OBJECT(check_box), "user_data", ma);
@@ -370,7 +327,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	
 	label = gtk_label_new(label_text);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 3);
-	spin_button = gtk_spin_button_new_with_range(0, 1000, 5);
+	spin_button = gtk_spin_button_new_with_range(10, 1000, 5);
 	g_object_set_data(G_OBJECT(spin_button), "user_data", ma);
 	g_object_set_data(G_OBJECT(spin_button), "prop_type",
 				GINT_TO_POINTER(PROP_SIZE));
@@ -387,7 +344,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	
 	label = gtk_label_new(_("System monitor speed: "));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 3);
-	spin_button = gtk_spin_button_new_with_range(0, 9999, 10);
+	spin_button = gtk_spin_button_new_with_range(50, 10000, 50);
 	g_object_set_data(G_OBJECT(spin_button), "user_data", ma);
 	g_object_set_data(G_OBJECT(spin_button), "prop_type",
 				GINT_TO_POINTER(PROP_SPEED));
@@ -406,7 +363,6 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, 0);
 	
 	notebook = gtk_notebook_new();
-	gtk_notebook_set_homogeneous_tabs(GTK_NOTEBOOK(notebook), TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(notebook), 5);
 	gtk_container_add(GTK_CONTAINER(frame), notebook);
 	
@@ -444,8 +400,7 @@ multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name
 	
 	if (dialog != NULL)
 	{
-	    gdk_window_show(dialog->window);
-	    gdk_window_raise(dialog->window);
+	    gtk_window_present (GTK_WINDOW (dialog));
 	    return;
 	}
 	
@@ -454,7 +409,9 @@ multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name
 	dialog = gtk_dialog_new_with_buttons(_("System Monitor Properties"), NULL, 0, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 				
 	fill_properties(dialog, ma);
-	
+
+	properties_set_insensitive(ma);
+				
 	g_signal_connect (G_OBJECT(dialog), "destroy",
 			G_CALLBACK(gtk_widget_destroyed), &dialog);
 	g_signal_connect(G_OBJECT(dialog), "response",
